==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ch19.h <==

#ifndef _C1_ch19_
#define _C1_ch19_

#ifdef __cplusplus
extern "C" {
#endif

extern void F25_199(EIF_REFERENCE);
extern EIF_CHARACTER_32 F25_212(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,224)
static EIF_REFERENCE F25_224_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_224(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,225)
static EIF_REFERENCE F25_225_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_225(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,226)
static EIF_REFERENCE F25_226_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_226(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,227)
static EIF_REFERENCE F25_227_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_227(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,228)
static EIF_REFERENCE F25_228_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_228(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,229)
static EIF_REFERENCE F25_229_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_229(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,230)
static EIF_REFERENCE F25_230_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_230(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,231)
static EIF_REFERENCE F25_231_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_231(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,232)
static EIF_REFERENCE F25_232_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_232(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,233)
static EIF_REFERENCE F25_233_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_233(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,234)
static EIF_REFERENCE F25_234_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_234(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,235)
static EIF_REFERENCE F25_235_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_235(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,236)
static EIF_REFERENCE F25_236_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_236(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,237)
static EIF_REFERENCE F25_237_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_237(EIF_REFERENCE);
extern void EIF_Minit19(void);
extern EIF_REFERENCE F733_5593(EIF_REFERENCE);
extern EIF_REFERENCE F738_5593(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C1/ch19.h <==

#ifndef _C1_ch19_
#define _C1_ch19_

#ifdef __cplusplus
extern "C" {
#endif

extern void F25_199(EIF_REFERENCE);
extern EIF_CHARACTER_32 F25_212(EIF_REFERENCE, EIF_CHARACTER_32);
RTOSHF (EIF_REFERENCE,224)
static EIF_REFERENCE F25_224_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_224(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,225)
static EIF_REFERENCE F25_225_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_225(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,226)
static EIF_REFERENCE F25_226_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_226(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,227)
static EIF_REFERENCE F25_227_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_227(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,228)
static EIF_REFERENCE F25_228_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_228(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,229)
static EIF_REFERENCE F25_229_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_229(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,230)
static EIF_REFERENCE F25_230_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_230(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,231)
static EIF_REFERENCE F25_231_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_231(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,232)
static EIF_REFERENCE F25_232_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_232(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,233)
static EIF_REFERENCE F25_233_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_233(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,234)
static EIF_REFERENCE F25_234_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_234(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,235)
static EIF_REFERENCE F25_235_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_235(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,236)
static EIF_REFERENCE F25_236_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_236(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,237)
static EIF_REFERENCE F25_237_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_237(EIF_REFERENCE);
RTOSHF (EIF_REFERENCE,238)
static EIF_REFERENCE F25_238_body(EIF_REFERENCE);
extern EIF_REFERENCE F25_238(EIF_REFERENCE);
extern void EIF_Minit19(void);
extern EIF_REFERENCE F735_5629(EIF_REFERENCE);
extern EIF_REFERENCE F740_5629(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
